#
# spec file for package powerpc-utils
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           powerpc-utils
Version:        1.3.10
Release:        150400.19.15.1
Summary:        Utilities for PowerPC Hardware
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://github.com/ibm-power-utilities/powerpc-utils
Source0:        https://github.com/ibm-power-utilities/powerpc-utils/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        nvsetenv
Patch1:         powerpc-utils-lsprop.patch
Patch2:         ofpathname_powernv.patch
Patch3:         fix_kexec_service_name_for_suse.patch
Patch4:         libvirt-service-dep.patch
Patch5:         lsslot-Explicity-declare-that-lmb_address-be-display.patch
Patch6:         lsslot-Fix-lsslot-c-mem-output-when-using-4GB-LMB-si.patch
Patch7:         lparstat-Fix-negative-values-seen-while-running-lpar.patch
Patch8:         lparstat-report-mixed-SMT-state.patch
Patch9:         lparstat-Fix-offline-threads-uninitialized-entries.patch
Patch10:        ppc64_cpu-Support-partial-SMT-level-through-SYS-FS-s.patch
Patch11:        lparstat-Fix-display-of-mode-for-dedicated-donating-.patch
Patch12:        lparstat-Fix-array-overflow-issue.patch
Patch13:        hcnmgr-Fix-setting-primary-slave-across-reboots.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libnuma-devel
BuildRequires:  librtas-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(zlib)
Requires:       bc
Requires:       coreutils
Requires:       findutils
Requires:       gawk
Requires:       grep
Requires:       kmod
Requires:       systemd-sysvinit
Requires:       udev
Requires:       util-linux
Recommends:     powerpc-utils-python
ExclusiveArch:  ppc ppc64 ppc64le
%{?systemd_requires}

%description
The powerpc-utils package provides a set of tools and utilities and
utilities for maintaining and enabling certain features of Linux on Power.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fvi
%configure \
    --disable-silent-rules \
    --with-systemd=%{_unitdir}
make CFLAGS="%{optflags}" %{?_smp_mflags}

%install
%make_install \
    rasdir=%{_sbindir} \
    mandir=%{_mandir}
%if !0%{?usrmerged}
mkdir %{buildroot}/sbin
ln -sf %{_sbindir}/lsprop %{buildroot}/sbin/lsprop
%endif
install -m 755 %{SOURCE1} %{buildroot}%{_sbindir}/nvsetenv
ln -sf serv_config %{buildroot}%{_sbindir}/uspchrp
ln -sf %{_mandir}/man8/serv_config.8 %{buildroot}%{_mandir}/man8/uspchrp.8
ln -sf drmgr %{buildroot}%{_sbindir}/drslot_chrp_slot
ln -sf drmgr %{buildroot}%{_sbindir}/drslot_chrp_pci
ln -sf drmgr %{buildroot}%{_sbindir}/drslot_chrp_cpu
ln -sf drmgr %{buildroot}%{_sbindir}/drslot_chrp_phb
ln -sf drmgr %{buildroot}%{_sbindir}/drslot_chrp_mem
ln -sf drmgr %{buildroot}%{_sbindir}/drslot_chrp_hea
ln -sf drmgr %{buildroot}%{_sbindir}/drmig_chrp_pmig

ln -s service %{buildroot}%{_sbindir}/rcsmt_off

install -m 644 systemd/hcn-init.service.suse %{buildroot}%{_unitdir}/hcn-init.service
mkdir -p %{buildroot}/usr/lib/powerpc-utils
install -m 644 scripts/functions.suse  %{buildroot}/usr/lib/powerpc-utils/functions.suse

# remove docu installed by make_install as we hand-install them in %%files
rm -rf %{buildroot}%{_docdir}/%{name}/*

%pre
%service_add_pre hcn-init.service smt_off.service smtstate.service

%post
%service_add_post hcn-init.service smt_off.service smtstate.service

%preun
%service_del_preun hcn-init.service smt_off.service smtstate.service

%postun
%service_del_postun hcn-init.service smt_off.service smtstate.service

%files
%license COPYING
%doc README Changelog
%{_mandir}/man*/*
%{_sbindir}/*
%{_bindir}/*
%if !0%{?usrmerged}
/sbin/lsprop
%endif
%dir %{_localstatedir}/lib/powerpc-utils
%config(noreplace) %{_localstatedir}/lib/powerpc-utils/smt.state
%dir /usr/lib/powerpc-utils
/usr/lib/powerpc-utils/functions.suse
%{_unitdir}/hcn-init.service
%{_unitdir}/smt_off.service
%{_unitdir}/smtstate.service

%changelog
* Tue Aug 15 2023 msuchanek@suse.com
- Tell kernel about the SMT value set by ppc64_cpu (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588).
  + ppc64_cpu-Support-partial-SMT-level-through-SYS-FS-s.patch
* Mon Jun  5 2023 msuchanek@suse.com
- Fix negative utilization value reported by lparstat -E (bsc#1212031)
  + lparstat-Fix-negative-values-seen-while-running-lpar.patch
- Fix lparstat error with mixed SMT state (bsc#1211883 ltc#02144)
  + lparstat-report-mixed-SMT-state.patch
  + lparstat-Fix-offline-threads-uninitialized-entries.patch
* Mon Jan  2 2023 msuchanek@suse.com
- Fix lparstat cpu mode display in a dedicated-donating LPAR (bsc#1206518 ltc#200949)
  + lparstat-Fix-display-of-mode-for-dedicated-donating-.patch
- Fix cpu utilization display
  + lparstat-Fix-array-overflow-issue.patch
- Fix setting primaty HNV link when using NM (bsc#1195404 ltc#196259).
  + hcnmgr-Fix-setting-primary-slave-across-reboots.patch
* Tue Oct  4 2022 msuchanek@suse.com
- Fix "lsslot -c mem" output when LMB size is set to 4GB (bsc#1202777 ltc#199300)
  + lsslot-Fix-lsslot-c-mem-output-when-using-4GB-LMB-si.patch
  + lsslot-Explicity-declare-that-lmb_address-be-display.patch
* Wed Jun 15 2022 msuchanek@suse.com
- Update to upstream version 1.3.10
  * ppc64_cpu: Add support to parse PAPR information for energy and frequency (bsc#1200465 ltc#197256 jsc#SLE-18129 jsc#PED-519)
  * powerpc-utils: Enhance error message when lparstat -E fails on max config systems (bsc#1198956 ltc#196850)
  * drmgr: Add support for 'acc' command (jsc#SLE-18644)
  * hcn-init.service: Add RemainAfterExit=yes
  * man/drmgr: fix multiple typos
  * hcnmgr: Add new feature "wicked" in HNV FEATURE list
  * hcnmgr: Update Makefile and powerpc-utils spec file to support HNV and wicked
  * hcnmgr: Fix NM HNV setting primary slave
  * hcnmgr: Add hcn-init.service.suse
  * hcnmgr: maintain hcnid state for later cleanup
  * hcnmgr: Support wicked HNV using new wicked functions for bonding
  * hcnmgr: Add new wicked functions for SuSE to manage bonding
  * hcnmgr: Factor out NetworkManager nmcli code
  * hcnmgr: Validate connection manager and add tracing option
  * bootlist: fix invalid hex number message
  * bootlist: fix passing -l flag to kpartx as -p delimiter value
  * lsslot: fix memory leak when listing IO slots
  * lsslot: Add new DRC type description strings for latest PCIe slot types
  * lparstat: report LPAR name from lparcfg
  * errinjct: sanitize devspec output of a newline if one is present
  * lparstat: Fix reported online memory in legacy format
  * ofpathname: Add support for NVMf devices
  * ofpathname: Fix nvme support in ANA mode
  * hcnmgr: Support vNIC as backup device
  * hcnmgr: Avoid hexdump squeezing consecutive identical bytes.
  * lsdevinfo: optimize criteria filtering
  * Remove upstreamed patches
  - lsdevinfo-optimize-criteria-filtering.patch
  - hcnmgr-Avoid-hexdum-squeezing-consecutive-identical-.patch
  - 0001-hcnmgr-Support-vNIC-as-backup-device.patch
  - 0002-hcnmgr-Remove-some-dead-code.patch
  - 0003-ofpathname-Fix-nvme-support-in-ANA-mode.patch
  - 0004-ofpathname-Add-support-for-NVMf-devices.patch
  - lparstat-Fix-reported-online-memory-in-legacy-format.patch
  - errinjct-sanitize-devspec-output-of-a-newline-if-one.patch
  - lparstat-report-LPAR-name-from-lparcfg.patch
  - lsslot-Add-new-DRC-type-description-strings.patch
  - 0001-Validate-connection-manager-and-add-option-to-trace-.patch
  - 0002-Factor-out-NetworkManager-nmcli-code.patch
  - 0003-Add-new-wicked-functions-from-suse-to-manage-bonding.patch
  - 0004-Support-wicked-HNV-using-new-wicked-functions-for-bo.patch
  - 0005-hcnmgr-maintain-hcnid-state-for-later-cleanup.patch
  - 0006-Add-hcn-init.service.suse.patch
  - 0007-Fix-NM-HNV-setting-primary-slave.patch
* Fri Feb 25 2022 msuchanek@suse.com
- Fix lsslot showing "Unknown slot type" for recent PCIe slot types (bsc#1196411 ltc#196505).
  - lsslot-Add-new-DRC-type-description-strings.patch
* Fri Feb 25 2022 msuchanek@suse.com
- Fix setting HNV primary slave with NM (bsc#1195404 ltc#196259).
  - 0007-Fix-NM-HNV-setting-primary-slave.patch
* Thu Feb 17 2022 msuchanek@suse.com
- lparstat: report LPAR name from lparcfg (bsc#1187716 ltc#193451).
  + lparstat-report-LPAR-name-from-lparcfg.patch
* Thu Feb 17 2022 msuchanek@suse.com
- Update HNV implementation (bsc#1195404 ltc#196259 jsc#SLE-23855).
  + 0001-Validate-connection-manager-and-add-option-to-trace-.patch
  + 0002-Factor-out-NetworkManager-nmcli-code.patch
  * 0003-Add-new-wicked-functions-from-suse-to-manage-bonding.patch
  + 0004-Support-wicked-HNV-using-new-wicked-functions-for-bo.patch
  + 0005-hcnmgr-maintain-hcnid-state-for-later-cleanup.patch
  + 0006-Add-hcn-init.service.suse.patch
  - 0001-Validate-connection-manager.patch
  - 0002-factor-out-NetworkManager-nmcli-code.patch
  - 0004-Support-wicked-HNV-using-new-wicked-interfaces-for.patch
  - 0005-Set-modprobe-bonding-max_bonds-0-option.patch
  - 0006-cleanup-hcnmgr-distro-and-service-detection.patch
  - 0007-Remove-wicked-ifup-calls-that-just-run-into-timeouts.patch
  - 0008-add-note-about-comma-in-hcnmgr-BONDOPTIONS.patch
  - 0009-Fix-to-call-wicked-ifreload-directly.patch
  - 0010-Fix-incorrect-parameters-to-suse_ifcfg_bond_create.patch
  - 0011-Fix-comment-about-setting-primary.patch
  - 0012-Description-and-indenting-corrections.patch
  - 0013-adjust-sourcing-path-of-the-functions.suse-library.patch
  - 0014-Enable-the-network-service-checks.patch
  - 0015-add-hcn-init.service.suse-service-covering-wicked.patch
  - 0016-functions.suse-fix-suse-wlist-utility-functions.patch
  - 0017-functions.suse-don-t-implicitly-set-primary-to-1st-s.patch
  - 0018-hcnmgr-add-x-option-to-trace-hcnmgr-script-execution.patch
  - 0019-check-platform-service-after-getopts-parsing.patch
  - 0020-call-less-intrusive-ifdown-ifup-in-rmdev_wicked.patch
  - 0021-call-ifup-instead-ifreload-in-config_vdevice_wicked.patch
  - 0022-split-scanhcn-function-into-nm-wicked-variants.patch
  - 0023-hcnmgr-merged-scanhcn_wicked-id-fix-and-comments.patch
  - 0024-Fix-race-with-udev-renaming-and-hcn-configure.patch
  - 0025-hcnmgr-remove-ifcfg-file-dump-from-scanhcn_wicked.patch
  - 0026-hcnmgr-move-sourcing-functions.suse-to-wicked-case.patch
  - 0027-hcnmgr-extend-suse-os-release-match.patch
* Mon Feb  7 2022 msuchanek@suse.com
- Fix HNV migration and other HNV issues (bsc#1195404 ltc#196259).
  + 0016-functions.suse-fix-suse-wlist-utility-functions.patch
  + 0017-functions.suse-don-t-implicitly-set-primary-to-1st-s.patch
  + 0018-hcnmgr-add-x-option-to-trace-hcnmgr-script-execution.patch
  + 0019-check-platform-service-after-getopts-parsing.patch
  + 0020-call-less-intrusive-ifdown-ifup-in-rmdev_wicked.patch
  + 0021-call-ifup-instead-ifreload-in-config_vdevice_wicked.patch
  + 0022-split-scanhcn-function-into-nm-wicked-variants.patch
  + 0023-hcnmgr-merged-scanhcn_wicked-id-fix-and-comments.patch
  + 0024-Fix-race-with-udev-renaming-and-hcn-configure.patch
  + 0025-hcnmgr-remove-ifcfg-file-dump-from-scanhcn_wicked.patch
  + 0026-hcnmgr-move-sourcing-functions.suse-to-wicked-case.patch
  + 0027-hcnmgr-extend-suse-os-release-match.patch
* Wed Feb  2 2022 msuchanek@suse.com
- Install smt.state as config file (bsc#1195413 ltc#193325).
* Thu Jan 27 2022 msuchanek@suse.com
- Add HNV wicked support (bsc#1193543 jsc#SLE-18127).
  + 0001-Validate-connection-manager.patch
  + 0002-factor-out-NetworkManager-nmcli-code.patch
  + 0003-Add-new-wicked-functions-from-suse-to-manage-bonding.patch
  + 0004-Support-wicked-HNV-using-new-wicked-interfaces-for.patch
  + 0005-Set-modprobe-bonding-max_bonds-0-option.patch
  + 0006-cleanup-hcnmgr-distro-and-service-detection.patch
  + 0007-Remove-wicked-ifup-calls-that-just-run-into-timeouts.patch
  + 0008-add-note-about-comma-in-hcnmgr-BONDOPTIONS.patch
  + 0009-Fix-to-call-wicked-ifreload-directly.patch
  + 0010-Fix-incorrect-parameters-to-suse_ifcfg_bond_create.patch
  + 0011-Fix-comment-about-setting-primary.patch
  + 0012-Description-and-indenting-corrections.patch
  + 0013-adjust-sourcing-path-of-the-functions.suse-library.patch
  + 0014-Enable-the-network-service-checks.patch
  + 0015-add-hcn-init.service.suse-service-covering-wicked.patch
- Install SUSE-specific scripts
* Wed Jan 12 2022 msuchanek@suse.com
- errinjct: sanitize devspec output of a newline if one is present (bsc#1194579 ltc#195746).
  + errinjct-sanitize-devspec-output-of-a-newline-if-one.patch
* Wed Jan  5 2022 msuchanek@suse.com
- Fix reported online memory in legacy format (bsc#1191147).
  + lparstat-Fix-reported-online-memory-in-legacy-format.patch
* Wed Jan  5 2022 msuchanek@suse.com
- Add support for vnic backup device for HNV (jsc#SLE-23097).
  + 0001-hcnmgr-Support-vNIC-as-backup-device.patch
  + 0002-hcnmgr-Remove-some-dead-code.patch
- Add support for NVMf devices (jsc#SLE-18643, bsc#1198728, ltc#197650).
  + 0003-ofpathname-Fix-nvme-support-in-ANA-mode.patch
  + 0004-ofpathname-Add-support-for-NVMf-devices.patch
* Fri Oct 29 2021 msuchanek@suse.de
- Avoid error with HCN IDs containing same consecutive bytes (bsc#1192095 ltc#194963).
  + hcnmgr-Avoid-hexdum-squeezing-consecutive-identical-.patch
* Fri Sep  3 2021 msuchanek@suse.de
- Optimize lsdevinfo filtering to prevent LPM timeouts (bsc#1189571 ltc#193419).
  + lsdevinfo-optimize-criteria-filtering.patch
* Fri Jul 30 2021 msuchanek@suse.de
- Update to version 1.3.9 (jsc#SLE-18645, bsc#1189015).
  - Remove upstreamed patches
  - 0001-HNV-fixes-for-qrydev-and-remove-lsdevinfo.patch
  - 0002-Disable-vnic-as-backup-vdevice-for-migratable-SR_IOV.patch
  - 0003-Clean-up-dead-network-config-interface-after-inactiv.patch
  - powerpc-utils-sys_ident-Skip-length-field-from-search.patch
  - 0001-hcnmgr-Avoid-cleanup-of-bond-interface-at-boot-time-.patch
  - 0002-hcnmgr-Wait-for-sysfs-device-ready-when-looking-up-d.patch
  - 0003-hcnmgr-Avoid-using-ifcfg-file-for-checking-bonding-i.patch
  - 0004-hcnmgr-Avoid-using-xargs-to-process-NM-show-connecti.patch
  - powerpc-utils-hcn-init-NM.patch
  - ofpathname-Use-NVMe-controller-physical-nsid.patch
  - powerpc-utils-Fix-ofpathname-race-with-udev-rename.patch
  - powerpc-utils-Update-ppc64-cpu-usage.patch
  - 0001-drmgr-don-t-open-sysfs-file-for-each-command.patch
  - 0002-drmgr-read-the-CPU-NUMA-topology.patch
  - 0003-drmgr-introduce-NUMA-based-LMB-removal.patch
  - drmgr-fix-remove-by-index-operation.patch
  - 0005-hcnmgr-When-trying-to-detect-HNV-bond-list-all-conne.patch
  - 0006-hcnmgr-Set-autoconnect-slaves-on-HNV-connections.patch
* Tue Jun 22 2021 msuchanek@suse.de
- Bring up the members of HNV link together with the HNV link
  (bsc#1187182 ltc#192954).
  + 0006-hcnmgr-Set-autoconnect-slaves-on-HNV-connections.patch
* Thu Jun 10 2021 msuchanek@suse.de
- When detecting HNV connection list all connections, not only active ones
  (bsc#1187148 ltc#192985).
  + 0005-hcnmgr-When-trying-to-detect-HNV-bond-list-all-conne.patch
* Wed Jun  2 2021 schwab@suse.de
- Don't install /sbin/lsprop if usrmerged
* Mon Apr 19 2021 msuchanek@suse.com
- Fix memore remove by index (bsc#1183958 ltc#192149).
  + drmgr-fix-remove-by-index-operation.patch
* Thu Apr  8 2021 msuchanek@suse.com
- Take into account NUMA topology when removing memory (bsc#1183958 ltc#192149).
  + 0001-drmgr-don-t-open-sysfs-file-for-each-command.patch
  + 0002-drmgr-read-the-CPU-NUMA-topology.patch
  + 0003-drmgr-introduce-NUMA-based-LMB-removal.patch
* Tue Apr  6 2021 msuchanek@suse.de
- The Install section of hcn-init should also refer to NetworkManager
  (bsc#1184136 ltc#192155).
  * Refresh powerpc-utils-hcn-init-NM.patch
* Tue Mar 30 2021 msuchanek@suse.com
- Require vim when NetworkManager is installed (bsc#1184136 ltc#192155).
- Start hcn-init with NetworkManager (bsc#1184136 ltc#192155).
  + powerpc-utils-hcn-init-NM.patch
* Thu Mar 18 2021 msuchanek@suse.de
- Add --version option to the ppc64_cpu usage (bsc#1183695 ltc#189235).
  + powerpc-utils-Update-ppc64-cpu-usage.patch
* Mon Mar 15 2021 msuchanek@suse.de
- ofpathname: Use NVMe controller physical nsid (bsc#1182020 ltc#191360).
  + ofpathname-Use-NVMe-controller-physical-nsid.patch
- HNV fixes (only NetworkManager supported) (jsc#SLE-13837 bsc#1181956 ltc#190722).
  + 0001-hcnmgr-Avoid-cleanup-of-bond-interface-at-boot-time-.patch
  + 0002-hcnmgr-Wait-for-sysfs-device-ready-when-looking-up-d.patch
  + 0003-hcnmgr-Avoid-using-ifcfg-file-for-checking-bonding-i.patch
  + 0004-hcnmgr-Avoid-using-xargs-to-process-NM-show-connecti.patch
- Fix ofpathname race with udev rename (bsc#1183496 ltc#191534).
  + powerpc-utils-Fix-ofpathname-race-with-udev-rename.patch
* Mon Jan  4 2021 msuchanek@suse.de
- sys_ident: Skip length field from search (bsc#1180540 ltc#190620).
  + powerpc-utils-sys_ident-Skip-length-field-from-search.patch
* Wed Dec 30 2020 msuchanek@suse.de
- Fixes for hybrid network virtualization (jsc#SLE-13837 bsc#1180129 ltc#190387)
  + 0001-HNV-fixes-for-qrydev-and-remove-lsdevinfo.patch
  + 0002-Disable-vnic-as-backup-vdevice-for-migratable-SR_IOV.patch
  + 0003-Clean-up-dead-network-config-interface-after-inactiv.patch
* Fri Sep 11 2020 msuchanek@suse.com
- Update to upstream version 1.3.8 (jsc#SLE-13291, jsc#SLE-13292,
    bsc#1180854 ltc#170517, bsc#1186487 ltc#177613)
  - Drop version suffix hack
  - Fix --with-systemd argument
  - Drop unneeded patch
  - systemd-dir.patch
  - Drop upstreamed patches
  - bug-1158312-parse-ibm-drc-info-property.patch
  - 0001-powerpc-utils-Suppress-errors-reading-kernel-files.patch
  - bsc1164726-search-only-part-of-sys.patch
  - bsc1171892-get-rid-of-trainling-NUL.patch
  - Fix-ofpathname-Could-not-retrieve-logical-device-nam.patch
  - ofpathname-Fix-udevadm-location.patch
  - ofpathname-make-goto_dir-canonicalize-directory-argu.patch
  - Drop compatibility patch - we are no longer near compatible with 1.3.6
  - Revert-lparstat-Show-available-physical-processors-i.patch
* Wed Jul 29 2020 ro@suse.de
- add patch fix_kexec_service_name_for_suse.patch
  on SUSE the service is called kexec-load.service instead
  of kexec.service (bsc#1174666)
* Fri Jun 26 2020 msuchanek@suse.de
- ofpathname: Fix lookup of disk partitions (bsc#1173403 ltc#186427)
  * Added ofpathname-make-goto_dir-canonicalize-directory-argu.patch
* Mon May 25 2020 msuchanek@suse.de
- Add patch metadata, refresh to upstream version where available.
  * Refreshed 0001-powerpc-utils-Suppress-errors-reading-kernel-files.patch
- The above patch was modified to fix bsc#1164068. Add a separate patch for
  that (bsc#1164068).
  * Added Fix-ofpathname-Could-not-retrieve-logical-device-nam.patch
- Stop using /sbin/udevadm symlink (boo#1160890).
  * Added ofpathname-Fix-udevadm-location.patch
* Wed May 20 2020 josef.moellers@suse.com
- Remove a trailing NUL ('\0') byte from a vendor_id contents.
  [bsc#1171892, bsc1171892-get-rid-of-trainling-NUL.patch]
* Wed May 20 2020 josef.moellers@suse.com
- Reduce the number of searches of /sys by searching directly in
  /sys/class/block. This patch obsoletes
  0002-Reduce-number-of-searches-of-sys-hierarchy.patch
  [bsc#1164726,
  0002-Reduce-number-of-searches-of-sys-hierarchy.patch,
  bsc1164726-search-only-part-of-sys.patch]
* Fri Feb 28 2020 josef.moellers@suse.com
- Reduce the number of searches of /sys by each invocation
  of 'ofpathname' to at most one (1) by caching the content of a
  single search into a file in /tmp, and using 'grep' to identify
  the appropriate files for further examination.
  [bsc#1164726,
  0002-Reduce-number-of-searches-of-sys-hierarchy.patch]
* Wed Feb 26 2020 josef.moellers@suse.com
- Fixed one instance where the previous change corrupted the
  exit status of a command.
  Redirected two error messages to stderr.
  [bsc#1164068,
  0001-powerpc-utils-Suppress-errors-reading-kernel-files.patch]
* Wed Jan 15 2020 josef.moellers@suse.com
- * Deal with error messages returned sometimes by evaluation
    of ${devspec} in 'ofpathname'.
  * Strip embedded nulls from values provided by kernel files.
  * Redirect more error messages to /dev/null
  [bsc#1116561,
  0001-powerpc-utils-Suppress-errors-reading-kernel-files.patch]
* Tue Dec  3 2019 josef.moellers@suse.com
- Parse new DRC Info: Define data structures to support parsing
  the new "ibm,drc-info" device tree property.  Integrate the new
  property information into the existing search mechanisms of the
  userspace 'drmgr' driver.
  [jsc#SLE-11094, jsc#SLE-11193, jsc#SLE-11092, jsc#SLE-11319, jsc#ECO-935,
  bsc#1158312, bsc#1161925, fate#326955
  bug-1158312-parse-ibm-drc-info-property.patch]
- Bump package version to be able to tell the fix for jsc#SLE-11092 is included
  Kernel can depend on the fixed version this way.
* Wed Jul  3 2019 jmoellers@suse.de
- Change the file permissions of smt_off.service to 644
  [powerpc-utils.spec, bsc#1139777]
* Thu Jun 27 2019 msuchanek@suse.de
- Drop compat patch on SLE 12 SP5.
- Remove unused macro
* Tue Jun 11 2019 josef.moellers@suse.com
- Update to version 1.3.7 (jsc#SLE-6176, bsc#1139456).
  - lparstat:
  - add an option to print the lparstat report similar to
    legacy lparstat tool
  - introduce the help command line option to print
    lparstat usage
  - restrict the physc and entc attribute values to two decimal
    places
  - correct calculation of physc to use tbr
  - Enable desired and maximum memory stats
  - Show available physical processors in the shared pool
  - scripts: Improve handling of errors from subsidiary scripts
  - man/update_flash:
  - Add details to extract rpm format image
  - Fix man page
  - ppc64_cpu: Limit number of CPUs for frequency calculation
  - lsslot:
  - Add ibm,dynamic-memory-v2 parsing capability
  - Split dynamic-memory v1 parsing into separate routine
  - Patch to display logical name using bootlist -o option
  - Refresh ofpathname_powernv.patch, systemd-dir.patch,
    Revert-lparstat-Show-available-physical-processors-i.patch
* Fri Jan 18 2019 msuchanek@suse.com
- ibmvscsis module we ship no longer needs support in powerpc-utils
  (bsc#1120474).
  - Remove Revert-ibmvscsis-remove-deprecated-ibmvscsis-scripts.patch
* Mon Dec 17 2018 msuchanek@suse.de
- Update to upstream v1.3.6 (FATE#326519, bsc#1120474)
  (see Changelog under powerpc-utils-1.3.6/Changelog)
- remove upstreamed patches
  - bootlist-Display-logical-name-using-bootlist-o-option.patch
  - lsslot-Add-ibm-dynamic-memory-v2-parsing-capability.patch
  - lsslot-Split-dynamic-memory-v1-parsing-into-separate.patch
  - powerpc-utils.bug-1109046_cpu-Limit-number-of-CPUs-for-frequency-calc.patch
- Patch to preserve compatibility with v1.3.4, v1.3.5
  + Revert-lparstat-Show-available-physical-processors-i.patch
- Keep support for ibmvscsis which we still ship
  + Revert-ibmvscsis-remove-deprecated-ibmvscsis-scripts.patch
* Mon Sep 24 2018 jloeser@suse.com
- limit number of CPUs for frequency calculation (bsc#1109046)
- added patches:
  * powerpc-utils.bug-1109046_cpu-Limit-number-of-CPUs-for-frequency-calc.patch
* Wed Aug  8 2018 msuchanek@suse.com
- Add support for ibm,dynamic-memory-v2 devicetree property (bsc#1103283)
  * lsslot-Split-dynamic-memory-v1-parsing-into-separate.patch
  * lsslot-Add-ibm-dynamic-memory-v2-parsing-capability.patch
- Display logical name using bootlist -o option (bsc#1099910)
  * bootlist-Display-logical-name-using-bootlist-o-option.patch
* Wed Jun 20 2018 jloeser@suse.com
- version update to 1.3.5 (fate#324948)
  (see Changelog under powerpc-utils-1.3.5/Changelog)
- removed patches:
  * drmgr-load-rpadlpar_io-on-C-as-well.patch
  * Revert-lsslot-free-lmb_list-on-error.patch
* Wed Apr  4 2018 tchvatal@suse.com
- Fix build failure (bsc#1088577)
* Thu Mar 22 2018 tchvatal@suse.com
- Use spec-cleaner to get %%license and SPDX-3.0 string
* Wed Mar 21 2018 msuchanek@suse.com
- Revert-lsslot-free-lmb_list-on-error.patch (bsc#1086268)
* Thu Dec 14 2017 msuchanek@suse.com
- Update drmgr-load-rpadlpar_io-on-C-as-well.patch to more robust solution.
* Thu Nov 30 2017 msuchanek@suse.com
- drmgr: load rpadlpar_io on -C as well (bnc#1064039, bsc#1070113)
  * drmgr-load-rpadlpar_io-on-C-as-well.patch
* Fri Oct 20 2017 jloeser@suse.com
- version update to 1.3.4 (fate#323767)
  (see Changelog under powerpc-utils-1.3.4/Changelog)
- modified patches:
  * libvirt-service-dep.patch
  * ofpathname_powernv.patch
  * powerpc-utils-lsprop.patch
  * systemd-dir.patch
- deleted paches:
  * powerpc-utils.bug-1039711_ofpathname-avoid-duplicate-entries-of-vFC-devices.patch
  * powerpc-utils.bug-1040076_test-for-zlib-presence-at-configuration-time.patch
  * powerpc-utils.bug-1041531_lsdevinfo-Add-support-for-vNIC-devices.patch
  * powerpc-utils.bug-1041531_ofpathname-Add-support-for-vNIC-devices.patch
  * powerpc-utils.bug-1042239_lsslot-Rectify-usr_drc_name-check.patch
  * powerpc-utils.bug-1043569_drmgr-Correct-drc-type-checking-in-check_kmods.patch
* Mon Jun 12 2017 msuchanek@suse.com
- add powerpc-utils.bug-1043569_drmgr-Correct-drc-type-checking-in-check_kmods.patch
  drmgr does not load rpadlpar_io module automatically (bsc#1043569)
* Fri Jun  2 2017 msuchanek@suse.com
- add powerpc-utils.bug-1042239_lsslot-Rectify-usr_drc_name-check.patch
  lsslot doesn't display the slot information (bsc#1042239)
* Tue May 30 2017 msuchanek@suse.com
- add patches to enable support for vNIC devices (bsc#1041531)
  * powerpc-utils.bug-1041531_lsdevinfo-Add-support-for-vNIC-devices.patch
  * powerpc-utils.bug-1041531_ofpathname-Add-support-for-vNIC-devices.patch
* Mon May 29 2017 jloeser@suse.com
- avoid duplicate entries of a Open Firmware device path to logical
  device path for vfc-client devices (bsc#1039711)
- test for zlib presence at configuration time (bsc#1040076)
- added patches:
  * powerpc-utils.bug-1039711_ofpathname-avoid-duplicate-entries-of-vFC-devices.patch
  * powerpc-utils.bug-1040076_test-for-zlib-presence-at-configuration-time.patch
* Mon Apr  3 2017 jloeser@suse.com
- version update to 1.3.3 (fate#321598)
  (see Changelog under powerpc-utils-1.3.3/Changelog)
- adjust url/source
- modified patches:
  * ofpathname_powernv.patch
  * powerpc-utils-lsprop.patch
  * systemd-dir.patch
- removed patches:
  * powerpc-utils-Include_GPL_header.patch
  * powerpc-utils-fix_integer_to_float_cast.patch
  * powerpc-utils-lparstat_Fix_segfault_when_parsing_proc_interrupts.patch
  * powerpc-utils-lparstat_Ignore_whitespace_at_beginning_of_proc_interrupts_SPU_line.patch
  * powerpc-utils-ofpathname_no_infinit_loop.patch
* Mon Nov 28 2016 normand@linux.vnet.ibm.com
- new powerpc-utils-ofpathname_no_infinit_loop.patch boo#1011529
* Mon Sep 12 2016 pth@suse.de
- Include the following new patches (bsc#998330):
  powerpc-utils-fix_integer_to_float_cast.patch
  powerpc-utils-Include_GPL_header.patch
  powerpc-utils-lparstat_Fix_segfault_when_parsing_proc_interrupts.patch
  powerpc-utils-lparstat_Ignore_whitespace_at_beginning_of_proc_interrupts_SPU_line.patch
* Mon Jul 18 2016 rw@suse.com
- Update to version 1.3.2. (bsc#986926, bsc#987687)
  (see Changelog under powerpc-utils-1.3.2/Changelog)
- dropped obsolete patch:
  * powerpc-utils.bug-982728_eeh_inject_error.patch
* Tue Jun 14 2016 tchvatal@suse.com
- Cleanup slightly with spec-cleaner and sort the dependencies
- Run the systemd scriptlets
- Provide the SUSE rc<service> compat link
* Mon Jun 13 2016 normand@linux.vnet.ibm.com
- Update to version 1.3.1+git20160328.57a03e8:
  + rtas_dbg: Do not exit on failure to read rtas token
  + drmgr: close opened dir
  + drmgr: free allocated hpdev in error path
  + ofpathanme: Convert logical device path to OF device path for NVMe devices
  + ofpathname: Convert OF device path to logical device path for NVMe devices
  + nvram: Correct valid partition name checking
  + lsslot: Update man page/usage statement to document required argument
  + drmgr: Load kernel modules for pci hotplug
  + snap: PowerNV platform is not correctly checked
  + Prep for powerpc-utils-1.3.1.
- change osc _service file to use tar_scm service (disabled by default)
* Tue Jun  7 2016 jloeser@suse.com
- fix error injection for EHH (extended error handling) (bsc#982728)
- added patches:
  * powerpc-utils.bug-982728_eeh_inject_error.patch
* Tue May 24 2016 dvaleev@suse.com
- Adjust dependant libvirt service name (libvirt-service-dep.patch)
* Tue May 24 2016 dvaleev@suse.com
- package smt-off.service (systemd-dir.patch)
* Thu Apr 14 2016 jloeser@suse.com
- version update to 1.3.1 (FATE#319933)
- modified patches:
  * ofpathname_powernv.patch
  * powerpc-utils-lsprop.patch
- removed patches:
  * 0001-nvram-Correct-valid-partition-name-checking.patch
* Tue Mar 29 2016 dvaleev@suse.com
- Fix nvram 0001-nvram-Correct-valid-partition-name-checking.patch
  (bsc#970463)
* Wed Mar  2 2016 jloeser@suse.com
- version update to 1.3.0 (FATE#319933)
  - see Changelog under powerpc-utils-1.3.0/Changelog
  - including fix for dynamic addition of memory (bsc#957445)
- removed patches:
  * powerpc-utils.bug-936383_snap-deprecated_warning_sles.patch
  * powerpc-utils.bug-945968_allocate-workarea-memory-instead-of-using-stac.patch
  * powerpc-utils.bug-945968_drmgr-Combine-the-init_node-and-examine_child-routin.patch
  * powerpc-utils.bug-948430-drmgr-Generate-error-message-when-PHB-is-not-found.patch
  * powerpc-utils.bug-952323_drmgr-free_slot_nodes_before_adding_slots.patch
  * powerpc-utils.bug-957448-correct_node_add_buffer_overflow.patch
* Thu Dec  3 2015 jloeser@suse.com
- fix for adding Houston adapter (bsc#957448)
- added patches:
  * powerpc-utils.bug-957448-correct_node_add_buffer_overflow.patch
* Thu Oct 29 2015 jloeser@suse.com
- free slot nodes before adding slots (bsc#952323)
- added patches:
  * powerpc-utils.bug-952323_drmgr-free_slot_nodes_before_adding_slots.patch
* Wed Oct  7 2015 jloeser@suse.com
- generate error message when PHB is not found (bsc#948430)
- added patches:
  * powerpc-utils.bug-948430-drmgr-Generate-error-message-when-PHB-is-not-found.patch
* Thu Oct  1 2015 jloeser@suse.com
- fix for adding spookfish 8GB FC adapter for DLPAR operations
  (bsc#945968)
- warn users about deprecated support SLES 12 onwards (bsc#936383)
- added patches:
  * powerpc-utils.bug-945968_allocate-workarea-memory-instead-of-using-stac.patch
  * powerpc-utils.bug-945968_drmgr-Combine-the-init_node-and-examine_child-routin.patch
  * powerpc-utils.bug-936383_snap-deprecated_warning_sles.patch
* Mon Jul 27 2015 dvaleev@suse.com
-  Don't require tgt. Linux as VIO server is not supported (bsc#940462)
* Fri Jul 24 2015 jloeser@suse.com
- version update to 1.2.26 (FATE#318009)
  - see Changelog under powerpc-utils-1.2.26/Changelog
  - including fix for drmgr -R replace issue (bsc#930153),
  - use sysfs migration store to initiate migration (bsc#926348),
  - fix for broken memory support for little endian (bsc#911679),
  - and do not remove the last CPU (bsc#901216)
- removed patches:
  * powerpc-utils.ofpathname.bootlist.patch
* Mon Jun  8 2015 dvlaeev@suse.com
- ofpathname_powernv.patch (boo#933651)
  If ofpathname is not supported on a platform, exit with 0.
  This will pevent grub2-install fail on PowerNV platform
* Mon Jun  8 2015 dvlaeev@suse.com
- Update to 1.2.24
    ofpathname: Convert logical path to OF device path for virtio-scsi devices
    Add support to convert logical device path to Open firmware device path
    for virtio-scsi devices.
    lsslot/drmgr: little endian support for memory
    This patch adds some support for memory slot listing
    and memory hotplugging on little endian systems.
    drmgr: Correct -s option handling
    The usage statement for drmgr claims that we can add/remove memory and cpus
    by drc name or drc index. The current code though assumes that any
    use of the -s flag to specify this defaults to drc name.
    This patch updates the option checking for memory and cpu operations to
    allow users to specify a drc index with the -s option. This will be
    handled the same way the -s option for pci devices is handled, assume it
    is a drc name unless it starts with '0x', indicating the string is
    really a hex value, and switching it to a drc index.
    drmgr: Correct null pointer usage
    We can't de-reference NULL pointers, it's not a nice thing to do.
    I found these during some debugging, correcting to avoid future bugs.
    ofpathname: Fix checking for hbtl
    Fix checking for hbtl in of2l_scsi ().
    snap in powerpc-utils 1.2.20 produces an archive with fstab and
    yaboot.conf files potentially containing cleartext passwords, and lacks
    a warning about reviewing this archive to detect included passwords,
    which might allow remote attackers to obtain sensitive information by
    leveraging access to a technical-support data stream.
    Solution:
    print a warning that confidential data may be collected via snap
    lparstat: using get_smt_mode when showing SMT info
    get_smt_state is used in the system_data structure to display both the
    shared_processor_mode and the smt_state members. After reviewing code and
    documentation, it seems that the information in smt_state is meant to be
    acquired from ppc64_cpu instead of lparcfg. With this change, the SMT listin
    will be determined by the output of ppc64_cpu --smt.
    ppc64_cpu: Allow builds without librtas
    Currently, --without-librtas disables ppc64_cpu.
    However, we only need librtas for the run-mode determination; other
    functions will work fine without it.
    This change allows ppc64_cpu to be built without librtas, by
    conditionally enabling run-mode, and restoring ppc64_cpu to be built
    when --without-librtas is given.
    We need to re-work src/Makefile.am a little here - we use the +=
    operator to include rtas-specific functionality, which means the
    with-librtas cases need to be listed before the without ones.
    We also need to #include stdint.h, as ppc64_cpu.c uses inttypes from
    here.
    drmgr: Correct the -s option handling correction
    In response to my earlier patch that attempted to correct the -s option hand
    for drmgr I introduced a bug in which the usr_drc_name could be NULL causing
    a segfault when attempting to use it.
    This patch adds a check to make sure it is not NULL.
    lparstat: using get_smt_mode when showing SMT info
    get_smt_state is used in the system_data structure to display both the
    shared_processor_mode and the smt_state members. After reviewing code and
    documentation, it seems that the information in smt_state is meant to be
    acquired from ppc64_cpu instead of lparcfg. With this change, the SMT listin
    will be determined by the output of ppc64_cpu --smt.
    drmgr: Correct the -s option handling correction
    In response to my earlier patch that attempted to correct the -s option hand
    for drmgr I introduced a bug in which the usr_drc_name could be NULL causing
    a segfault when attempting to use it.
    This patch adds a check to make sure it is not NULL.
    lparstat: remove "On" from possible smt output
    The SMT row will only display the number of enabled SMT threads if
    SMT is enabled.
    ppc64_cpu: output only the number of SMT threads when smt is on
    This patch removes "SMT is on" as a possible output when the smt option
    is used. Instead, only the number of SMT threads will be displayed.
- Drop upstreamed patches
    powerpc-utils-bug-886123_01-l2of_scsi.patch
    powerpc-utils-bug-886123_02-of2l_scsi.patch
    powerpc-utils.snap-confidential_config_files_warning.patch
* Thu Mar 19 2015 dvaleev@suse.com
- Get rid of tgt dependency. We're no longer interested in running
  Linux as VIO scsi server.
* Thu Mar 12 2015 p.drouand@gmail.com
- Remove dependency on fillup and insserv; the package provides
  neither sysconfig file nor sysvinit script
* Tue Oct 28 2014 jloeser@suse.com
- add a warning that confidential data may be collected via snap
  (bnc#883174, CVE-2014-4040)
- added patches:
  * powerpc-utils.snap-confidential_config_files_warning.patch
* Fri Sep 19 2014 stefan.fent@suse.com
- Fix OF Patchnames with vscsi (bnc #886123)
- added patches:
  powerpc-utils-bug-886123_01-l2of_scsi.patch
  powerpc-utils-bug-886123_02-of2l_scsi.patch
* Thu Sep  4 2014 jloeser@suse.com
- version update to 1.2.22 (BNC#894855)
  - ppc64_cpu: Be verbose about inconsistant SMT state
  - ppc64_cpu: Remove parameter from do_info
  - nvram: Handle endianness in the nvram --unzip option
  - drmgr/lsslot: increase number of max cpu threads
  - lsslot/drmgr: little endian support for memory
  - lsslot/drmgr: little endian support for cpu
- removed patches:
  * powerpc-utils.endianness_for_unzip_option.patch
* Wed Jul 16 2014 jloeser@suse.com
- fix for nvram --unzip option to handle endianness (BNC#887275)
- added patch:
  * powerpc-utils.endianness_for_unzip_option.patch
* Thu Jul  3 2014 pth@suse.de
- Update to 1.2.21 (bnc#884709):
  * uesensor: remove unused platform variable
  * nvram: restrict --nvram-size to 16 byte multiples
  * nvram: fix memory corruption when nvram->nbytes is less than
    actual nvram size
  * set_power_on: handle endianess reading max latency
  * ppc64_cpu: handle endianess in rtas sysparm buffer
  * uesensor: fix endian issues reading device-tree
  * serv_config: handle endianess in sysparm buffer
  * lsslot: fix segfault when lmb_list->lmbs is NULL
  * ppc64_cpu: update access validation routines
  * update_flash: Fix typo in man page
  * update_flash_nv: Display current FW version
  * snap: Fix typo in output display
  * ppc64_cpu: Let kernel validate subcore options
  * ofpathname: Convert OF path to logical names for usb devices
  * ofpathname: Convert logical device path to OF format for
    usb devices
  * drmgr: Update action option validation
  * ppc64_cpu: Add option --threads-per-core
  * Move librtas error code to common directory.
  * add sys/time.h and gettimeofday detection to configure.ac
    courtesy autoscan
  * check for and use gcc hardening flags if available
  * remove autogenerated files
- Refresh powerpc-utils.ofpathname.bootlist.patch.
- Remove Autor line and clean section from spec file.
- Add Changelog to documentation.
* Tue Mar 25 2014 jloeser@suse.com
- version update to 1.2.20 (BNC#869852)
  see changelog for changes
* Tue Mar  4 2014 jloeser@suse.com
- version update to 1.2.19 (BNC#866675)
  see changelog for changes
* Tue Feb 11 2014 dvlaeev@suse.com
- Change license to CPL-1.0
* Fri Jan 10 2014 jloeser@suse.com
- version update to 1.2.18 (FATE#315785, FATE#316153, FATE#315495)
  See changelog for changes
* Mon Dec  9 2013 dvaleev@suse.com
- add ppc64le
* Fri Jul 12 2013 dvaleev@suse.com
- update to 1.2.17
  See changelog for changes
* Mon Jul  1 2013 dvaleev@suse.com
- Recommend powerpc-utils-python instead of Requireing it. The
  pacakge is not mandatory
* Sun Feb 24 2013 dvaleev@suse.com
- Update to 1.2.16
  * The drmgr command does not currently allow users to specify the
    drc index of the resource they wish to add/remove. This patch
    updates the drmgr command so that users can specify either a
    drc name or a drc index with the -s option.
  * This functionality is needed for the upcoming userspace handling
    of PRRN RTAS events. The rtas_errd will already have the drc
    index for the resources it needs, adding the capability to
    parse drc names from the device tree is not supported in
    rtas_errd though.
  * Update the man page for update_flash which had an out of date link
    to instructions for resetting a managed system to a non-partitioned
    configuration.
  * The upstream kernel has a feature in the pseries PCI code called DDW
    that inserts TCEs transparently to device drivers. The upstream kernel
    was recently sent a fix for DLPAR that ensured those TCEs would get
    cleared upon DLPAR remove (http://patchwork.ozlabs.org/patch/213735/),
    but for it to work, we need a corresponding change to drmgr for, at
    least, PHB remove, so that the notifier chain has fired before we call
    into the slot isolate code. Without such a change, there is no way to
    ensure the DDW TCEs are cleared, and the DLPAR will always fail.
  * Add and use dt_swap_int() to byte swap on little endian.
  * Also declare buf as unsigned char, so that we don't sign extend when
    printing values from it.
* Thu Dec 20 2012 dvaleev@suse.com
- Update to 1.2.15
  * The frequency determination for a system can fail if we can not
    open enough files to make the determination. This patch
    pre-emptively updates the rlimit to ensure we can open all the
    files necessary.
  * The latest firmware levels allow for setting different power
    savings modes. This updates the ppc64_cpu command to display
    the power savings mode that is currently set for the partition,
    or for the partition and the system if they are different,
    when displaying the results for the --frequency option.
  * Add support to convert device-mapper multipath device names to
    OFW device path.
    As multipath devices are seen by the OFW as multiple
    (equivalent) devices, only one of them is printed so we don't
    break user scripts expecting one line output. We can add an
    option later to print all the paths to the multipath device.
  * We have introduced full fledged Light Path Diagnostics support
    on PowerLinux. To bring all Light Path Diagnostics related
    code into common tree and re-use common functionalities across
    tools, we have re-implemented usysident/usysattn commands.
    Light Path Diagnostics including new implentation of
    usysident/usysattn will be hosted in PowerLinux diagnostic
    package (ppc64-diag).
    ppc64-diag source:
    http://sourceforge.net/projects/linux-diag/files/ppc64-diag
    This will introduce package conflict between ppc64-diag and
    powerpc-utils. To avoid the conflict we need to deprecate the
    usysident/usysattn commands from powerpc-utils.
    This patch deprecates usysident/usysattn commands.
  * Update the values reported in the ppc64_cpu --frequency output to
    be displayed to three digits of precision instead of two.
    This update to help with test teams that are making this update
    to their code base already so as to get this precision in
    the reporting.
- Comment Obsoletes/Provides for now, there is no such packages for
  long time already. Let see if somebody will complain
- Require powerpc-utils-python package
* Tue Dec 18 2012 dvaleev@suse.com
- Update to 1.2.14
- The latest kernels allow for users to get/set the DSCR value on a per proces
  This allows for more refined DSCR setting in applications. This is implement
  by using the ptrace peekuser capabilites in the kernel and simply doing a
  ptrace attach and peek from the ppc64_cpu command. Note: this does not actua
  stop the process we are attaching to while under ptrace control.
  The patch does a little more than just adding this functionality since the
  - -dscr commad now takes an optional -p <pid> option. This required an
  updated to the command parsing code to allow this.
- Includes the status field for Ethernet devices.  This field is necessary for
  the End-to-End Virtual Device View feature.  The field is blindly set to 1
  because we're trying to mimic AIX's lsdevinfo behavior that always sets it t
  unless the device doesn't have a driver, which can't happen in Linux.
- Adding more power specific files/commands to snap
- There are two parameters on lparstat, count and interval, that were
  undocumented on the man page. This patch adds these parameters to the
  option section in the lparstat manpage.
- snap uses temporary directory to gather system data (files and command
  output), and finally creates compressed output file in tar or tar.gz
  format. We do not need to keep the temporary directory.
  snap now deletes the temprory directory it used.
- Currently by default snap output is stored in snap.tar.gz file. This
  makes difficult to identify when the snap output was collected.
  This patch introduces new option -t which adds hostname adds and
  system time to output filename. With -t output filename will be
  snap-<hostname>-<systemtime>.tar.gz. This patch also creates
  snap_commands directory inside $outdir to save output of commands
  executed by snap.
- Restrict the unsafe constructs by using "use strict" perl pragma
  and hence make snap code better.
- Adds support for physical ethernet devices so that the HMCs end-to-end
  virtual device view can show SR-IOV VFs. Moves common virtual and physical
  ethernet code to show_eth() function
* Fri Aug 10 2012 dvaleev@suse.com
- add wrapper for nvsetenv which just wraps nvram
* Sun Jun 10 2012 dvaleev@suse.com
- Update to 1.2.12
  Fix update_flash man page
- Adjust Requires
* Wed Nov  2 2011 dvaleev@suse.com
- Update to 1.2.11
  Drop powerpc-utils.insserv-ibmvscsis.patch as script
    no longer shipped with tarball
- Adds support to the bootlist script to be able to supply a
  multipath device     as a parameter. The script will now
  properly handle setting up the bootlist for all paths to
  a multipath device.
- Fixes ofpathname OF to logical conversion for LUN zero
  for VFC devices.
- Add --unzip and --ascii options to nvram command, for
  examination of oops/panic reports captured in lnx,oops-log
  or ibm,rtas-log.
- On newer kernels the dscr value is a per-process value and a new
    interface (dscr_default) is used to update the dscr value for
    all new processes on the system.
- require librtas-devel as librtas has been splitted
* Thu Aug  4 2011 dvaleev@novell.com
- Update to 1.2.10 release
- Man page for lparstat
- Adds support to ofpathname for HFI network devices. Since the current driver
    does not attach to any bus and there is no way to correlate between the devi
    ce tree and the hf device in sysfs, we have to make some assumptions in how
    the two are related.
- Adds support for some new ipr SAS adapters which have a new device path
  representation in Open Firmware. This also fixes the OF to logical translation
  for LSI based SAS adapters as well as fixes issues seen with some FC devices.
- Adds the page coalescing statistics to the output of amsstat
- The number removable memory sections can not be determined if AMS is
    active because LMBs that are not marked 'is_removable' could still be
    removed if the balloon driver owns that memory.  Therefore the check
    comparing the user-specified quanity of LMBs to add/remove is invalid.
    If AMS ballooning is active, skip the check for how many LMBs are
    removable and try the operation.
- The snap man page indicates that the file /var/log/platform
    is collected.  This is not always true and can cause some confusion
    since the file does not exist on newer systems.  To avoid confusing
    users who might think the file should be collected, remove it
    from the man page listing of files.
    The /var/log/platform file is where the rtas_errd daemon used to write
    its data before the advent of servicelog.  On older systems that may
    still be running an older rtas_errd daemon (diagela package) this
    file would still exist so we should still try to collect it in the
    snap command if its present.
- The get_bus_id function takes a location code and then searches
    /sys/bus/pci/slots/*/phy_location for a slot with the matching location
    code.  Without this patch the comparison only considers the characters
    up to the length of the input location which can cause a false match.
    For example, the following to would match.
    Input location: U5877.001.00H4031-P1
    False match:    U5877.001.00H4031-P10
    ^ Comparison stops here
    The length of the input is 23 characters and the first 23 characters
    are compared, this leaves off the last '0' on the string to compare and
    erroneously returns the wrong bus.
    In the case of a PHB remove operation, this can cause the incorrect slot
    (and associated devices) to be powered off.
- lparstat command.
* Tue Jan 11 2011 dvaleev@novell.com
  Changes in 1.2.6 version:
- Introduce the lsdevinfo utility.  This command is used to provide the HMC
    or IVM with name information for virtual devices so they can be
    matched against the VIOS names.
- The OpenFirmware binding for Fibre Channel devices permits any leading
  zeros in the LUN field to be stripped, but does not require it. Fix
  ofpathname to handle this case when translating OF pathname to logical
  device name.
- According to PAPR, we need to call activate-firmware after a migration,
  which we weren't doing. Add this call after updating the device tree.
- Add another device tree update call after it to ensure the SLB size is
  correctly updated in the kernel.
- The ppc64_cpu command needs to properly turn off the smt snooze delay.
  The current code does not handle the option 'off', it should as this
  is regarded as a delay of -1.
- The /usr/sbin/rsct/bin/refrsrc command forces a refresh of the HMC/IVM
  and RMC status after a migration occurs.  We should do this from the
  drmgr command instead of assuming servicelog is installed.  A failure
  to invoke this command can cause additional migrations to be delayed
  for up to 10 minutes while the framework refreshes itself.
- This is really more of a re-write than an update.  The ppc64_cpu command
  is being ported from Perl to C to support new functionality.  This
  update introduces two new pieces of functionality to the command.
- New amsstat command. amsstat - display a list of Active Memory Sharing (AMS)
  statistics.
- Update the find command in get_vfc_wwpn() to handle being passed a
  symbolic link.  Previously this lead to an infinite loop due to the
  possible circular nature of sysfs.
- Change the name format for vio devices and correct indentation.
- The sysfs_dev_path member of the dr_node struct is a char[] and needs to
  be treated as such.  this fixes a bug where the sysfs_dev_path is
  treated as a char * and returning invalid info when the buffer is
  actually empty.
- Cpu add failures need to return 1 instead of -1.  A return code of -1
  causes the IVM to think there has been a really bad error and the IVM
  will wait 15 minutes prior to re-trying the operation.
- Logical device name to open firmware path translation for fibre-channel
  devices can fail on systems where the fc_remote_ports file in sysfs
  has a slightly different name.  On some systems this file appears as
  fc_remote_ports:rport-X:Y-Z.  This patch corrects the lookup of this
  file.
- The logic in get_node_by_name() currently does not return when it finds a
  child with the name being search for.  This would mean that a command
  such as `drmgr -Q -c port -s "Port 1" -w 0 -d 3` would always return:
  drmgr: Port 1 not owned by partition
- DR commands shouldn't take long to complete, but having both an entry and
  exit timestamp eliminates the guessing and can point people in the
  correct direction while they debug issues.
* Mon Jan  3 2011 dvaleev@novell.com
- move %%post to %%install
* Wed Dec 29 2010 dvaleev@novell.com
- as-needed fix
* Thu Dec 23 2010 dvaleev@novell.com
- update to version 1.2.6
- drop unneeded patches
- papr sources merged to main tree upstream
* Tue Dec 16 2008 olh@suse.de
- fix endless loop in nvsetenv when /dev/nvram contains only zeros
* Tue Oct 28 2008 olh@suse.de
- Release hotplug children of slots on dlpar remove (bnc#439491 - LTC48584)
* Mon Oct 27 2008 olh@suse.de
- use linux,phandle for memory add when ibm,phandle is not available.
  (bnc#438685 - LTC49075)
* Wed Oct 15 2008 olh@suse.de
- fix memory hotplug remove (bnc#435181 - LTC48640)
- provide compat symlinks (bnc#435543 - LTC49095)
* Wed Oct 15 2008 olh@suse.de
- require tgt unconditionally
* Thu Oct  9 2008 olh@suse.de
- require tgt because the ibmvscsis kernel driver is SLES10 only
  (bnc#433956)
* Mon Oct  6 2008 sassmann@suse.de
- update powerpc-utils-papr to 1.1.3 (bnc#430790)
  * Corrected string length calculation in of_to_full_path()
  * Removed call to release_lmb() during recovery of memory add.
    In certain cases this can leead to an oops becasue we try to
    remove non-existant lmbs.
- remove patch powerpc-utils-papr.lsslot.patch (upstream)
* Tue Sep 30 2008 olh@suse.de
- fix malloc size lsslot (bnc#430790 - LTC48583)
* Mon Sep 15 2008 olh@suse.de
- update powerpc-utils-papr to 1.1.2 (bnc#417533)
  compile with new libservicelog sources
* Fri Aug 29 2008 olh@suse.de
- updated powerpc-utils and -papr to version 1.1.1 (bnc#417555)
  support for virtual FC devices
* Thu Aug 28 2008 olh@suse.de
- move Required-Start/Stop to ShouldStart/Stop
* Wed Aug  6 2008 ro@suse.de
- add exclusivearch to specfile
* Thu Jun 26 2008 olh@suse.de
- fix open flags in drmgr, fix buffer handling in serv_config.c
- updated powerpc-utils-papr to version 1.1.0 (fate#304103)
  * Add drmgr and lsslot commands
  * Updated serv_config with processor-module-info parameter
* Fri May  9 2008 olh@suse.de
- sysfs layout changed once again
  look for directories when searching for kernel device names to
  avoid multiple matches
* Thu Mar  6 2008 sassmann@suse.de
- updated powerpc-utils to version 1.1.0
  * Added lsprop command.
  * ofpathname updated to detect PATA devices, whitespace cleanup, add
    platform detection and add -a option to print device tree aliases.
  * ofpathaname: Updates to properly parse paths for SAS drives.
  * Added ppc64_cpu script from Anton Blanchard which allows you to set the
    cpu SMT, DSCR and smt-snooze-delay settings.
- adapted patch powerpc-utils-lsprop.patch to new release
- adapted patch powerpc-utils-nvsetenv.patch to new release
* Tue Mar  4 2008 sassmann@suse.de
- removed petitboot from powerpc-utils (handled in separate
  package petitboot now)
* Thu Jan 17 2008 sassmann@suse.de
- use kernel 2.6.24-rc8 for booting petitboot
- update kernel config file to 2.6.24
- update geninitrd.sh
  * spawn ttys for debugging
  * syslog to tty8
  * update udev rule
  * include setctsid
- update to petitboot-0.2
- adapt patches to petitboot-0.2
- update to libtwin-0.0.3 (required for petitboot-0.2)
* Thu Jan 17 2008 olh@suse.de
- update ofpathname for the sysfslayout of the week,
  to fix bootlist -m normal eth1
* Fri Jan  4 2008 sassmann@suse.de
- add sixaxis joypad support to petitboot
- enable joystick support in kernel config
- split petitboot patches into small components
- patch libtwin to latest b9b2acf28d1ebad52de372a181dadf73455ad4de
  snapshot from git://anongit.freedesktop.org/git/twin
* Thu Oct 18 2007 sassmann@suse.de
- reapplied fixed patch powerpc-utils.ofpathname.show_of_path.patch
- patch powerpc-utils.ofpathname.correct-vscsi-scan.patch obsolete
- patch powerpc-utils.bootlist.easy-network-dev.patch obsolete
* Tue Oct 16 2007 sassmann@suse.de
- update to powerpc-utils-1.0.6
- update to powerpc-utils-papr-1.0.4
- disabled patches
  Patch2: powerpc-utils.ofpathname.show_of_path.patch
  Patch3: powerpc-utils.ofpathname.correct-vscsi-scan.patch
  Patch4: powerpc-utils.bootlist.easy-network-dev.patch
* Tue Sep 11 2007 sassmann@suse.de
- rework of petitboot patches
* Tue Aug 28 2007 sassmann@suse.de
- added ps3 network shutdown patch
  (ps3-gelic-fix-ifup-hangup.diff)
- petitboot-editor fix right shift key not working correctly
* Fri Aug 24 2007 sassmann@suse.de
- petitboot now reads timeout from config file
  (petitboot.timeout-from-config.patch)
* Thu Aug 23 2007 sassmann@suse.de
- fixed bug in libtwin which reversed key_up/key_down handling
  (libtwin.key-up-down.patch)
- petitboot-editor now handles ctrl and shift keys
  (petitboot-editor-enhancement.patch)
* Wed Aug 22 2007 sassmann@suse.de
- changed ps3fb size from 18 to 9MB to save RAM in ps3config
* Mon Aug 20 2007 sassmann@suse.de
- added missing '-' key to petitboot editor
- enable /proc/config.gz (CONFIG_IKCONFIG_PROC=y)
- added udevinfo to initrd
* Wed Aug 15 2007 sassmann@suse.de
- added kernel patch for HDMI/DVI autodetection
- added Samsung226bw to monitor quirk list
- added ps3-storage-fix-probe-region-loop.diff to fix random
  misdetection of storage devices
- added patch to prevent focus disappearing when switching windows
  petitboot.focus-disappear-on-switch-fix.patch
- improved petitboot editor to support more keys
* Tue Aug 14 2007 sassmann@suse.de
- changed petitboot editor keyboard layout to QWERTY
- removed debug output from petitboot
- improved event handling in petitboot
* Mon Aug 13 2007 sassmann@suse.de
- added rudimentary editor for petitboot
- resized petitboot loading jpg to gain some space
- disabled wireless extension in kernel config
* Fri Aug 10 2007 sassmann@suse.de
- added petitboot features
  * implemented timeout handling
  * default timeout of 20s
  * added fancy loading screen
- fixed ps3-utils naming issue in petitboot
- fixed dhcp handling, now sets subnet mask correctly
* Tue Aug  7 2007 olh@suse.de
- fix filelist to not include /usr/lib/debug, to fix build
  bz2 sources
  remove unclosed if
  run ldconfig also in postun because rpmlint wants it that way
* Tue Jul 31 2007 sassmann@suse.de
- added ps3-utils to installation section
* Tue Jul 24 2007 sassmann@suse.de
- fixed dns resolving for ps3
- network configuration with ifconfig
* Mon Jul 23 2007 sassmann@suse.de
- updated ps3-utils to git tag
  99570babcccbb964aeb402cb4458406d3ca02773
- cleanup of geninitrd.sh
- smaller ps3-kernel
- added patch for reboot problem
* Fri Jul 13 2007 sassmann@suse.de
- updated otheros.bld to build from kernel source 2.6.22
  updated .config file
* Thu Jun 21 2007 sassmann@suse.de
- updated ps3-utils to git tag
  99570babcccbb964aeb402cb4458406d3ca02773
* Thu Jun 21 2007 sassmann@suse.de
- autoselect first boot entry in petitboot
* Wed May 16 2007 olh@suse.de
- add vim-base to Buildrequires, for xxd
* Fri May 11 2007 sassmann@suse.de
- fixed udev on ps3 to detect devices properly (geninitrd.sh)
  added icons for petitboot
* Mon May  7 2007 sassmann@suse.de
- generate otheros.bld from kernel source 2.6.16
  added libtwin
  added petitboot
  added ps3pf-utils
* Mon Feb 19 2007 olh@suse.de
- handle network devices with flat device-tree
* Fri Oct 13 2006 olh@suse.de
- handle short writes to /dev/nvram, current kernels limit write
  size to PAGE_SIZE
* Mon May 15 2006 olh@suse.de
- the kernel ibmvscsis patch was updated to provide the type
  field again. remove last patch again (173880 - LTC23729)
* Sat Apr 29 2006 olh@suse.de
- /sys/bus/vio/drivers/ibmvscsis/30000003/bus0/target0/type was
  removed from sles10, it was always unused.
  remove it from vscsisadmin and ibmvscsis.conf man page
* Tue Mar 28 2006 olh@suse.de
- allow bootlist -m normal eth0, no further options required
* Mon Feb 20 2006 olh@suse.de
- correct vscsi path detection (#142637)
  update to powerpc-utils 1.0.0
  * Added devball target to builds.
  update to powerpc-utils-papr 1.0.1
  * Updated usysident with the ability to manipulate SES-controlled LEDs.
* Mon Feb  6 2006 olh@suse.de
- use show_of_path.sh in ofpathname for scsi (#142637)
* Tue Jan 31 2006 olh@suse.de
- strip neededforbuild, remove libselinux
* Fri Jan 27 2006 olh@suse.de
- move lsprop and nvsetenv from util-linux
* Mon Jan 23 2006 olh@suse.de
- rename to powerpc-utils 0.0.1, includes further fixes
  (fate #140406 - 144758)
* Fri Oct 28 2005 olh@suse.de
- update to version 2.5.3 (130214 - LTC19273)
  fixes for ofpathname
* Wed Oct 26 2005 olh@suse.de
- add LSB header to ibmvscsis runlevel script
* Wed Oct 26 2005 olh@suse.de
- update to version 2.5.2 (130214 - LTC19273)
  small fix for rtas_dump
* Wed Oct 19 2005 olh@suse.de
- update to version 2.5, many new cmdline utils
* Mon Oct 18 2004 olh@suse.de
- update to version 1.1 (#47323 - LTC11869)
  force of the block size to 4k in update_flash;
  this is required for flasing firmware on power5 systems
  (the firmware image will be corrupted otherwise)
* Sun Jun 13 2004 meissner@suse.de
- Updated to latest IBM requested version. LTC#9266/SUSE#41907
  - lots of enhancements to nvram, and update_flash.
* Sun Dec 14 2003 olh@suse.de
- read nvram in small chunks, not at once
* Mon Sep  8 2003 olh@suse.de
- update to current version
* Thu Feb  6 2003 olh@suse.de
- inital package version 0.4
